pub enum JsonSchemaParseError {
Serde(Error),
UnknownField {
key: String,
path: String,
},
Io(Error),
}Expand description
Error when parsing a JSON Schema with the given settings.
Variants
Serde(Error)
JSON or serde error (invalid JSON, wrong types, etc.).
UnknownField
An unknown key was present and strict ingestion was enabled.
Fields
Io(Error)
I/O error when reading from a reader or file.